# Generated by Django 2.0.1 on 2018-02-08 06:43

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('jacc', '0010_auto_20180201_0734'),
        ('jbank', '0014_payout_payoutstatus'),
    ]

    operations = [
        migrations.CreateModel(
            name='Refund',
            fields=[
                ('payout_ptr', models.OneToOneField(auto_created=True, on_delete=django.db.models.deletion.CASCADE, parent_link=True, primary_key=True, serialize=False, to='jbank.Payout')),
            ],
            options={
                'verbose_name_plural': 'refunds',
                'verbose_name': 'refund',
            },
            bases=('jbank.payout',),
        ),
        migrations.RemoveField(
            model_name='refundrecord',
            name='accountentry_ptr',
        ),
        migrations.DeleteModel(
            name='RefundRecord',
        ),
    ]
