# -*- coding: utf-8 -*-
# Generated by Django 1.11 on 2017-11-02 22:38
from __future__ import unicode_literals

from django.db import migrations, models
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('jbank', '0004_statementfile'),
    ]

    operations = [
        migrations.AddField(
            model_name='statementfile',
            name='created',
            field=models.DateTimeField(blank=True, db_index=True, default=django.utils.timezone.now, verbose_name='created'),
        ),
    ]
