# Generated by Django 2.0 on 2018-01-26 09:09

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('jbank', '0012_auto_20180126_0858'),
    ]

    operations = [
        migrations.AlterField(
            model_name='refundrecord',
            name='state',
            field=models.CharField(blank=True, choices=[('W', 'refund.waiting.payout'), ('P', 'refund.paid'), ('C', 'refund.canceled')], db_index=True, default='W', max_length=1, verbose_name='state'),
        ),
    ]
