{% extends "admin/change_form.html" %}

{% load i18n admin_urls admin_static admin_modify %}

{% block object-tools-items %}
    <li>
        {% url opts|admin_urlname:'history' original.pk|admin_urlquote as history_url %}
        <a href="{% add_preserved_filters history_url %}" class="historylink">{% trans "History" %}</a>
    </li>
    <li>
        {% url 'admin:jbank_referencepaymentrecord_batch_changelist' original.id|admin_urlquote as records_url %}
        <a href="{% add_preserved_filters records_url %}" class="historylink">{% trans "Reference Payment Records" %}</a>
    </li>
    {% if has_absolute_url %}<li><a href="{{ absolute_url }}" class="viewsitelink">{% trans "View on site" %}</a></li>{% endif %}
{% endblock %}

{% block after_field_sets %}{{ block.super }}
{% endblock %}
